pub struct InstanceInformation {
    pub ip_addresses: Vec<IpAddr>,
    pub ports: Vec<u16>,
    pub attributes: HashMap<String, Option<String>>,
}
Represents a single instance of the service. Notice that it is not possible to associate a port to a single ip address, due to limitations of the DNS protocol

Fields

ip_addresses: Vec<IpAddr>

Ips for this instance

ports: Vec<u16>

Ports for this instance

attributes: HashMap<String, Option<String>>

Attributes for this instance

Implementations

source

impl InstanceInformation

source

pub fn new() -> Self

Creates an empty InstanceInformation

source

pub fn into_records<'a>( self, service_name: &Name<'a>, ttl: u32 ) -> Result<Vec<ResourceRecord<'a>>, SimpleMdnsError>

Transform into a Vec

source

pub fn get_socket_addresses(&self) -> impl Iterator<Item = SocketAddr> + '_

Creates a Iterator of SocketAddr for each ip address and port combination